@@ -31,7 +31,7 @@ eqs = [
     D(y5) ~ (-1.745 * y5 + k5 * y6 + k5 * y7),
     D(y6) ~ (-k2 * y6 * y8 + k4 * y4 + k1 * y5 - k5 * y6 + k4 * y7),
     D(y7) ~ (k2 * y6 * y8 - k6 * y7),
-    D(y8) ~ (-k2 * y6 * y8 + k6 * y7)
+    D(y8) ~ (-k2 * y6 * y8 + k6 * y7),
 ]
 
 @mtkcompile model = System(eqs, t)
@@ -40,29 +40,47 @@ struct Tag end
 T = typeof(ForwardDiff.Tag(Tag(), Float64))
 
 u0 = [
-    Dual{T, Float64, 7}(1.8983788068509213,
-        ForwardDiff.Partials((0.6970981087506788, 0.0, 0.0, 0.0, 0.0, 0.0,
-            0.0))),
+    Dual{T, Float64, 7}(
+        1.8983788068509213,
+        ForwardDiff.Partials(
+            (
+                0.6970981087506788, 0.0, 0.0, 0.0, 0.0, 0.0,
+                0.0,
+            )
+        )
+    ),
     Dual{T, Float64, 7}(0.0, ForwardDiff.Partials((0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0))),
     Dual{T, Float64, 7}(0.0, ForwardDiff.Partials((0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0))),
     Dual{T, Float64, 7}(0.0, ForwardDiff.Partials((0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0))),
     Dual{T, Float64, 7}(0.0, ForwardDiff.Partials((0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0))),
     Dual{T, Float64, 7}(0.0, ForwardDiff.Partials((0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0))),
     Dual{T, Float64, 7}(0.0, ForwardDiff.Partials((0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0))),
-    Dual{T, Float64, 7}(0.0057, ForwardDiff.Partials((0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0)))
+    Dual{T, Float64, 7}(0.0057, ForwardDiff.Partials((0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0))),
 ]
 
 p = [
-    Dual{T, Float64, 7}(1.5174072564237708,
-        ForwardDiff.Partials((0.0, 0.38355212192378396, 0.0, 0.0, 0.0, 0.0,
-            0.0))),
+    Dual{T, Float64, 7}(
+        1.5174072564237708,
+        ForwardDiff.Partials(
+            (
+                0.0, 0.38355212192378396, 0.0, 0.0, 0.0, 0.0,
+                0.0,
+            )
+        )
+    ),
     Dual{T, Float64, 7}(0.43, ForwardDiff.Partials((0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0))),
     Dual{T, Float64, 7}(8.32, ForwardDiff.Partials((0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0))),
-    Dual{T, Float64, 7}(268.1197063467946,
-        ForwardDiff.Partials((0.0, 0.0, 44.91823438292696, 0.0, 0.0, 0.0,
-            0.0))),
+    Dual{T, Float64, 7}(
+        268.1197063467946,
+        ForwardDiff.Partials(
+            (
+                0.0, 0.0, 44.91823438292696, 0.0, 0.0, 0.0,
+                0.0,
+            )
+        )
+    ),
     Dual{T, Float64, 7}(0.69, ForwardDiff.Partials((0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0))),
-    Dual{T, Float64, 7}(20.0, ForwardDiff.Partials((0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0)))
+    Dual{T, Float64, 7}(20.0, ForwardDiff.Partials((0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0))),
 ]
 
 prob = SteadyStateProblem(model, u0, p)
